#
# spec file for package pentobi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pentobi
Version:        26.3
Release:        1.2
Summary:        Program to play the board game Blokus
License:        GPL-3.0-only
Group:          Amusements/Games/Strategy/Other
URL:            https://pentobi.sourceforge.net/
Source:         https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  cmake >= 3.18
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  extra-cmake-modules
BuildRequires:  itstool
BuildRequires:  kio-devel
BuildRequires:  libxslt-tools
BuildRequires:  pkgconfig
BuildRequires:  qt6-linguist-devel
BuildRequires:  rsvg-convert
BuildRequires:  pkgconfig(Qt6Concurrent)
BuildRequires:  pkgconfig(Qt6Core) >= 6.5
BuildRequires:  pkgconfig(Qt6QuickControls2)
BuildRequires:  pkgconfig(Qt6WebView)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(Qt6Xml)
BuildRequires:  pkgconfig(appstream)
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
# unresolvable: nothing provides pkgconfig(Qt6WebView)
ExclusiveArch:  x86_64 aarch64
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  gcc12
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc-c++
%endif

%description
Pentobi is a computer opponent for the board game Blokus with
support for Classic, Duo, Junior, Trigon, and Nexos game variants.
Different levels of playing strength are available. Pentobi can
save and load games along with comments and move variations.

%prep
%setup -q

%build
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
export CC="gcc-12"
export CXX="g++-12"
%endif
%cmake -DCMAKE_BUILD_TYPE=Release -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON .
%make_jobs VERBOSE=1

%install
%cmake_install

%files
%license LICENSE.md
%doc AUTHORS.md NEWS.md README.md
%{_bindir}/pentobi
%{_datadir}/applications/io.sourceforge.pentobi.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/mime/packages/*.xml
%{_datadir}/metainfo/io.sourceforge.pentobi.appdata.xml

%changelog
* Fri Feb  7 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 26.3
  * Disabled native text rendering on desktop, which did not work
    well on some platforms.
  * Indicate support for mobile devices in metainfo file.
* Mon Jan 27 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 26.2
  * Added release info to appstream file.
- Update to version 26.1
  * Added developer id to appstream file.
* Fri Jan 24 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 26.0
  * French translation of the manual.
  * Fixed default window size.
  * Mobile layout is now used by default on devices with small
    screens.
  * New option --desktop.
  * Minimum required Qt version is now 6.5.
* Fri Nov 15 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 25.2
  * Fixed display problems in help window in some situations.
  * Workaround for a Qt bug that made window disappear on some
    platforms when returning from fullscreen.
- Update to version 25.1
  * Fixed menu text rendering issues on newer versions of KDE.
* Sat Apr 27 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 25.0
  * Don't ask for continuing computer move anymore if computer is
    to play in current position after program startup.
  * Workaround for QTBUG-119198 (Disabled menu item
    indistinguishable from enabled one).
  * Compile QML sources into executable, which avoids problems of
    QML cache sometimes not being updated if installed via Flatpak.
  * Fixed formatting of written game files.
  * Improved visibility of analysis graph lines in theme System.
  * Minor fixes.
* Sat Feb 10 2024 Carsten Ziepke <kieltux@gmail.com>
- Use gcc12 for openSUSE Leap, fixes building
* Wed Feb  7 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 24.0:
  * Removed GNOME thumbnailer and man pages, which didn't work anyway if installed via Flatpak.
    Use --help or --help-all to list the command line options for pentobi.
  * Removed rarely used menu item Export Ascii Art.
  * Enable only menu item Save As but not Save if game has no filename yet.
  * Don't refuse to open SGF files with non-SGF text after tree
    (e.g. files that were corrupted on Android by bug fixed in version 23.1).
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 23.1:
  * Overwriting game file on Android with shorter file created
    corrupted file.
* Thu Mar  9 2023 Dmitriy Perlow <dap.darkness@gmail.com>
- ExclusiveArch because of pkgconfig(Qt6WebView) availability.
* Mon Mar  6 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 23.0
  * Use native file dialogs on Linux to make loading and saving of
    games work with flatpak.
  [#] This adds a run-time dependency on package
  [#]    qml6-module-qtquick-dialogs (on Debian).
  * Prefix MIME config and icons with io.sourceforge.pentobi, such
    that registering Pentobi as an app for its game files works
    with flatpak.
  * Removed option to disable animations.
  * Removed menu item Open Clipboard.
  * Require C++ compiler with C++20 support.
  * Minimum required Qt version is now 6.4
  * Removed custom CMake module to find path of Docbook XSL and let
    the local XML catalog do the mapping between URL and path.
  * Don't initialize move number dialog with current move but show
    it as placeholder text.
- Update to version 22.0
  * Fixed game analysis hanging on some platforms.
  * Don't use custom menu implementation, which caused problems in
    dark mode on Android and KDE 5. As a consequence, shortcuts
    are no longer shown on the menu but documented in the Pentobi
    manual.
  * Made navigation links in help viewer part of the scrollable
    page to avoid a bug in Qt that made the text sometimes
    disappear if a navigation link was pressed with a scrolled
    page.
  * Help window shortcuts stopped working after mouse click with
    Qt 6.4.
* Tue Jan 31 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 21.1
  * Fixed game analysis hanging on some platforms.
  * Don't use custom menu implementation, which caused problems in
    dark mode on Android and KDE 5. As a consequence, shortcuts
    are no longer shown on the menu but documented in the Pentobi
    manual.
  * Made navigation links in help viewer part of the scrollable
    page to avoid a bug in Qt that made the text sometimes
    disappear if a navigation link was pressed with a scrolled
    page.
  * Help window shortcuts stopped working after mouse click with
    Qt 6.4.
* Wed May 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 21.0
  * New help viewer implementation, which includes DocBook files
    in the resources. This avoids using an external browser, which
    did not work with all installation directories on Ubuntu 21.10
    because Firefox and Chromium have restricted access to local
    files, or using WebView, which is not supported on all Linux
    architectures or in Qt 6.0/6.1.
  * Fixed visibility of labels on Callisto 1x1-piece in dark theme.
  * Fixed rendering issues on Android with Qt 6.3.0.
  * Fixed detection of loaded files or autosaved games modified by
    another application.
* Sun Jan 23 2022 Martin Hauke <mardnh@gmx.de>
- Update to versino 20.0
  * More general workaround to avoid crashes with Qt 5.15 related
    to storing QDateTime in QSettings.
  * Workarounds for bugs in Qt 6.2 that sometimes caused wrong
    positions of unplayed pieces.
  * Install application and mimetype bitmap icons for multiple
    sizes.
  * Show error message if launching web browser failed.
  * Minimum required CMake version is now 3.18.
* Mon Dec  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 19.1
  * Workaround for a crash at exit in some situations.
  * Dialog for starting rated game was not shown after accepting a
    dialog to discard current game.
  * Avoid deprecated mimetypes tag in AppStream file.
  * Avoid warnings with Qt 6 caused by deprecated signal handler
    syntax.
* Sat Apr 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 19.0
  * The minimum required Qt version is now 5.15.
  * Support compilation with Qt 6.
  * The desktop version now always displays the manual with an
    external browser, which removes the dependency on the Qt
    WebView library and the compilation option
    PENTOBI_OPEN_HELP_EXTERNALLY.
  * The Qt SVG library is no longer needed.
  * Loading game files in encodings other than UTF-8 is no
    longer supported.
* Thu Mar  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 18.5
  * Require GNU gettext >=0.19.6, which has built-in support for
    AppData, such the appstream package is no longer needed for
    compilation.
  * Added missing include that broke the compilation with GCC 11
  * Complete Russian translation of the manual.
* Sat Nov 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 18.4
  * Avoid unnecessary dependency on QtQml QML module.
  * Aborting computer play with the Stop button did not work
    reliably when the computer played multiple colors at low
    levels.
  * New Russian translation of manual.
* Wed Nov  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 18.3
  * Made opening of recent rated games from rating dialog work
    again.
  * New Russian UI translation.
  * Menu shortcuts are no longer supported.
* Sun Oct 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 18.2
  * Fixed truncated submenu in desktop version with Qt 5.15.
  * Updated bugtracker link.
* Fri Jun 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 18.1
  * Fixed compilation with Qt 5.15.
  * Updated AndroidManifest.xml for usage with Qt 5.15.
  * HTML manual generation failed with older versions of DocBook XSL.
* Mon May 11 2020 Martin Hauke <mardnh@gmx.de>
- Updat to version 18.0
  * The minimum required Qt version is now 5.12.
  * Fixed crash if application was closed while game analysis was
    running.
  * Added missing include that broke the compilation with GCC 10
    if compiled with PENTOBI_BUILD_GTP=1.
* Wed Nov  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 17.3
  * Don't use Fusion style on desktop anymore because it is
    currently broken on some Linux distributions (QTBUG-77107).
  * Added more search hints for location of DocBook XSL.
- Update to version 17.2
  * New Spanish translation
  * New Game button and menu item were not enabled if no moves were
    played but an analysis graph existed (e.g. after analyzing a
    game and then undoing all moves).
  * Clear autosaved analysis if autosaved game corresponded to a
    file that no longer exists.
* Thu Jun 13 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release, version 17.1
  * Move generation hung if a move generation using search was
    aborted and the next move generation used the opening book.
  * Added search hint for DocBook XSL for compilation on OpenSUSE.
- Remove patch (fixed upstream):
  * pentobi-add-proper-docbook-path.patch
* Thu Jun  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release, version 17.0
  * see /usr/share/doc/packages/pentobi/NEWS for all changes
  * Add patch:
  - pentobi-add-proper-docbook-path.patch
    Add hint path so cmake can find html/chunk.xsl
* Wed Apr 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release, version 16.3
  * see /usr/share/doc/packages/pentobi/NEWS for all changes
* Thu Jul 19 2018 mardnh@gmx.de
- Specfile cleanup
* Fri Jun 29 2018 huaren.zhong@gmail.com
- Rebuild for Fedora
* Mon Jan  4 2016 juhaninumminen0@gmail.com
- Created by borrowing from existing pentobi.spec files
- Add subpackage kde-thumbnailer
- Build with -O3 to make higher levels faster
